@@ -91,11 +91,11 @@ void meskalin::usage(char *self)
 {
 printf("
 
-	MESKALIN v1.1
+	MESKALIN v1.2
 	by:	dodo [dodo@fuckmicrosoft.com]
-	url:	http://darkwired.ath.cx/
+	url:	http://darkwired.ath.cx/projects/meskalin/
 
-	// parport LED control software for the brainwave machine by CYBRG/ASM @ hackcanada
+	// parport LED control software
 	// \'the future of your mind relies on wetwire\'
 
 	thnx to:	tsunami
@@ -142,7 +142,12 @@ return ret;
 void meskalin::startio(void)
 {
 
-	if(ioperm(base,1,1))
+#ifdef __FreeBSD__
+	if(i386_set_ioperm(base, 1, 1))
+#else
+	if(ioperm(base, 1, 1))
+#endif
+
 	{
 	printf("ioperm() failed\n");
 	exit(0);
@@ -150,6 +155,15 @@ void meskalin::startio(void)
 
 }
 
+void meskalin::outio(int value)
+{
+#ifdef __FreeBSD__
+	outb(base, value);
+#else
+	outb(value, base);
+#endif
+}
+
 void meskalin::normal(int frequency)
 {
 int sleepy;
@@ -163,9 +177,9 @@ printf("usleep() delay: %i microseconds\n", sleepy*2);
 
 	while(1)
 	{
-		outb(255,base);
+		outio(255);
 		usleep(sleepy);
-		outb(0,base);
+		outio(0);
 		usleep(sleepy);
 	}
 }
@@ -185,9 +199,9 @@ printf("usleep() delay: %i microseconds\n", sleepy*2);
 
 	while(1)
 	{
-		outb(170,base);
+		outio(170);
 		usleep(sleepy);
-		outb(85,base);
+		outio(85);
 		usleep(sleepy);
 	}
 }
@@ -207,13 +221,13 @@ printf("strlen: %i\n", strlen(type));
 		printf("usleep() delay: %i microseconds\n", sleepy*4);
 		while(1)
 		{
-			outb(40,base);
+			outio(40);
 			usleep(sleepy);
-			outb(17,base);
+			outio(17);
 			usleep(sleepy);
-			outb(130,base);
+			outio(130);
 			usleep(sleepy);
-			outb(68,base);
+			outio(68);
 			usleep(sleepy);
 		}
 	}
@@ -226,13 +240,13 @@ printf("strlen: %i\n", strlen(type));
 		printf("usleep() delay: %i microseconds\n", sleepy*4);
 		while(1)
 		{
-			outb(40,base);
+			outio(40);
 			usleep(sleepy);
-			outb(68,base);
+			outio(68);
 			usleep(sleepy);
-			outb(130,base);
+			outio(130);
 			usleep(sleepy);
-			outb(17,base);
+			outio(17);
 			usleep(sleepy);
 		}
 	}
@@ -245,13 +259,13 @@ printf("strlen: %i\n", strlen(type));
 		printf("usleep() delay: %i microseconds\n", sleepy*4);
 		while(1)
 		{
-			outb(34,base);
+			outio(34);
 			usleep(sleepy);
-			outb(17,base);
+			outio(17);
 			usleep(sleepy);
-			outb(136,base);
+			outio(136);
 			usleep(sleepy);
-			outb(68,base);
+			outio(68);
 			usleep(sleepy);
 		}
 	}
@@ -264,13 +278,13 @@ printf("strlen: %i\n", strlen(type));
 		printf("usleep() delay: %i microseconds\n", sleepy*4);
 		while(1)
 		{
-			outb(34,base);
+			outio(34);
 			usleep(sleepy);
-			outb(68,base);
+			outio(68);
 			usleep(sleepy);
-			outb(136,base);
+			outio(136);
 			usleep(sleepy);
-			outb(17,base);
+			outio(17);
 			usleep(sleepy);
 		}
 	}
@@ -292,9 +306,9 @@ startio();
 		// 2.3.7.8	:5.6.1.4
 		// 2.4.64.128	:16.32.1.8
 		// 198		:57
-			outb(198, base);
+			outio(198);
 			usleep(sleepy);
-			outb(57, base);
+			outio(57);
 			usleep(sleepy);
 		}
 	}
@@ -309,9 +323,9 @@ startio();
 		// 6.7.2.3	:5.8.1.4
 		// 32.64.2.4	:16.128.1.8
 		// 102		:153
-			outb(102, base);
+			outio(102);
 			usleep(sleepy);
-			outb(153, base);
+			outio(153);
 			usleep(sleepy);
 		}
 	}
@@ -326,9 +340,9 @@ startio();
 		// 5.6.1.2	:8.7.3.4
 		// 16.32.1.2.	:128.64.4.8
 		// 51		:204
-			outb(51, base);
+			outio(51);
 			usleep(sleepy);
-			outb(204, base);
+			outio(204);
 			usleep(sleepy);
 		}
 	}
@@ -343,9 +357,9 @@ startio();
 		// 4.3.6.7	:1.2.5.8
 		// 8.4.32.64	:1.2.16.128
 		// 108		:147
-			outb(108, base);
+			outio(108);
 			usleep(sleepy);
-			outb(147, base);
+			outio(147);
 			usleep(sleepy);
 		}
 	}
@@ -354,7 +368,7 @@ startio();
 void meskalin::reset(void)
 {
 startio();
-outb(0,base);
+outio(0);
 printf("parport output resetted\n");
 exit(0);
 }
@@ -364,7 +378,7 @@ void meskalin::address(int address)
 printf("meskalin parport outputting started\n");
 printf("sending \'1\' to parport adress: %i\n", address);
 startio();
-outb(address,base);
+outio(address);
 printf("done...\n");
 exit(0);
 }
@@ -387,7 +401,7 @@ printf("meskalin parport outputting started\n");
 printf("sending \'1\' to led %i\n", led);
 printf("sending \'1\' to parport adress: %i\n", address);
 startio();
-outb(address,base);
+outio(address);
 printf("done...\n");
 exit(0);
 }
