@@ -3,7 +3,14 @@
 #include	<stdlib.h>
 #include	<unistd.h>
 #include	<string.h>
-#include	<sys/io.h>
+
+#ifdef __FreeBSD__
+	#include	<sys/types.h>
+	#include	<machine/cpufunc.h>
+	#include	<machine/sysarch.h>
+#else
+	#include	<sys/io.h>
+#endif
 
 /* pick your parport adress */
 #define base 0x378
@@ -32,8 +39,9 @@ public:
 	void	address(int address);
 	void	led(int led);
 	
-		//misc
+		//io
 	void	startio(void);
+	void	outio(int value);
 
 };
 
